pub fn read(bytes: &[u8]) -> Result<Opened<Hprz>, FormatError>Expand description
Reads a container, taking a design of an older version to the current one.
read_within with MAX_UNPACKED_BYTES.
Errors
As read_within.
pub fn read(bytes: &[u8]) -> Result<Opened<Hprz>, FormatError>Reads a container, taking a design of an older version to the current one.
read_within with MAX_UNPACKED_BYTES.
As read_within.