pub fn from_json(text: &str) -> Result<DesignFile, FormatError>Expand description
Reads a document from its JSON text, taking one of an older version to the current one.
read_json with the version the text was written in dropped.
Errors
FormatError: not JSON, not an hpr design, a version this reader doesn’t take, or not
valid.